# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/connection.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ibc.core.commitment.v1 import commitment_pb2 as ibc_dot_core_dot_commitment_dot_v1_dot_commitment__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ibc/core/connection/v1/connection.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\'ibc/core/commitment/v1/commitment.proto\"\x90\x02\n\rConnectionEnd\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x31\n\x08versions\x18\x02 \x03(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12,\n\x05state\x18\x03 \x01(\x0e\x32\x1d.ibc.core.connection.v1.State\x12@\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12-\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\":\x04\x88\xa0\x1f\x00\"\xb2\x02\n\x14IdentifiedConnection\x12\x19\n\x02id\x18\x01 \x01(\tB\r\xf2\xde\x1f\tyaml:\"id\"\x12\'\n\tclient_id\x18\x02 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x31\n\x08versions\x18\x03 \x03(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12,\n\x05state\x18\x04 \x01(\x0e\x32\x1d.ibc.core.connection.v1.State\x12@\n\x0c\x63ounterparty\x18\x05 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12-\n\x0c\x64\x65lay_period\x18\x06 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\":\x04\x88\xa0\x1f\x00\"\xaa\x01\n\x0c\x43ounterparty\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12/\n\rconnection_id\x18\x02 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12:\n\x06prefix\x18\x03 \x01(\x0b\x32$.ibc.core.commitment.v1.MerklePrefixB\x04\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\x1c\n\x0b\x43lientPaths\x12\r\n\x05paths\x18\x01 \x03(\t\"I\n\x0f\x43onnectionPaths\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\r\n\x05paths\x18\x02 \x03(\t\"5\n\x07Version\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x10\n\x08\x66\x65\x61tures\x18\x02 \x03(\t:\x04\x88\xa0\x1f\x00\"U\n\x06Params\x12K\n\x1bmax_expected_time_per_block\x18\x01 \x01(\x04\x42&\xf2\xde\x1f\"yaml:\"max_expected_time_per_block\"*\x99\x01\n\x05State\x12\x36\n\x1fSTATE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x11\x8a\x9d \rUNINITIALIZED\x12\x18\n\nSTATE_INIT\x10\x01\x1a\x08\x8a\x9d \x04INIT\x12\x1e\n\rSTATE_TRYOPEN\x10\x02\x1a\x0b\x8a\x9d \x07TRYOPEN\x12\x18\n\nSTATE_OPEN\x10\x03\x1a\x08\x8a\x9d \x04OPEN\x1a\x04\x88\xa3\x1e\x00\x42>Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.connection_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/cosmos/ibc-go/v2/modules/core/03-connection/types'
  _STATE._options = None
  _STATE._serialized_options = b'\210\243\036\000'
  _STATE.values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._options = None
  _STATE.values_by_name["STATE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \rUNINITIALIZED'
  _STATE.values_by_name["STATE_INIT"]._options = None
  _STATE.values_by_name["STATE_INIT"]._serialized_options = b'\212\235 \004INIT'
  _STATE.values_by_name["STATE_TRYOPEN"]._options = None
  _STATE.values_by_name["STATE_TRYOPEN"]._serialized_options = b'\212\235 \007TRYOPEN'
  _STATE.values_by_name["STATE_OPEN"]._options = None
  _STATE.values_by_name["STATE_OPEN"]._serialized_options = b'\212\235 \004OPEN'
  _CONNECTIONEND.fields_by_name['client_id']._options = None
  _CONNECTIONEND.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _CONNECTIONEND.fields_by_name['counterparty']._options = None
  _CONNECTIONEND.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _CONNECTIONEND.fields_by_name['delay_period']._options = None
  _CONNECTIONEND.fields_by_name['delay_period']._serialized_options = b'\362\336\037\023yaml:\"delay_period\"'
  _CONNECTIONEND._options = None
  _CONNECTIONEND._serialized_options = b'\210\240\037\000'
  _IDENTIFIEDCONNECTION.fields_by_name['id']._options = None
  _IDENTIFIEDCONNECTION.fields_by_name['id']._serialized_options = b'\362\336\037\tyaml:\"id\"'
  _IDENTIFIEDCONNECTION.fields_by_name['client_id']._options = None
  _IDENTIFIEDCONNECTION.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _IDENTIFIEDCONNECTION.fields_by_name['counterparty']._options = None
  _IDENTIFIEDCONNECTION.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _IDENTIFIEDCONNECTION.fields_by_name['delay_period']._options = None
  _IDENTIFIEDCONNECTION.fields_by_name['delay_period']._serialized_options = b'\362\336\037\023yaml:\"delay_period\"'
  _IDENTIFIEDCONNECTION._options = None
  _IDENTIFIEDCONNECTION._serialized_options = b'\210\240\037\000'
  _COUNTERPARTY.fields_by_name['client_id']._options = None
  _COUNTERPARTY.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _COUNTERPARTY.fields_by_name['connection_id']._options = None
  _COUNTERPARTY.fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _COUNTERPARTY.fields_by_name['prefix']._options = None
  _COUNTERPARTY.fields_by_name['prefix']._serialized_options = b'\310\336\037\000'
  _COUNTERPARTY._options = None
  _COUNTERPARTY._serialized_options = b'\210\240\037\000'
  _CONNECTIONPATHS.fields_by_name['client_id']._options = None
  _CONNECTIONPATHS.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _VERSION._options = None
  _VERSION._serialized_options = b'\210\240\037\000'
  _PARAMS.fields_by_name['max_expected_time_per_block']._options = None
  _PARAMS.fields_by_name['max_expected_time_per_block']._serialized_options = b'\362\336\037\"yaml:\"max_expected_time_per_block\"'
  _STATE._serialized_start=1135
  _STATE._serialized_end=1288
  _CONNECTIONEND._serialized_start=131
  _CONNECTIONEND._serialized_end=403
  _IDENTIFIEDCONNECTION._serialized_start=406
  _IDENTIFIEDCONNECTION._serialized_end=712
  _COUNTERPARTY._serialized_start=715
  _COUNTERPARTY._serialized_end=885
  _CLIENTPATHS._serialized_start=887
  _CLIENTPATHS._serialized_end=915
  _CONNECTIONPATHS._serialized_start=917
  _CONNECTIONPATHS._serialized_end=990
  _VERSION._serialized_start=992
  _VERSION._serialized_end=1045
  _PARAMS._serialized_start=1047
  _PARAMS._serialized_end=1132
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1binjective/wasmx/v1/tx.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"X\n\x18MsgExecuteContractCompat\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05\x66unds\x18\x04 \x01(\t\"0\n MsgExecuteContractCompatResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x80\x01\n\x11MsgUpdateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\x12\x11\n\tgas_limit\x18\x03 \x01(\x04\x12\x11\n\tgas_price\x18\x04 \x01(\x04\x12\x1b\n\radmin_address\x18\x05 \x01(\tB\x04\xc8\xde\x1f\x01\"\x1b\n\x19MsgUpdateContractResponse\"?\n\x13MsgActivateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"\x1d\n\x1bMsgActivateContractResponse\"A\n\x15MsgDeactivateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"\x1f\n\x1dMsgDeactivateContractResponse2\xea\x03\n\x03Msg\x12t\n\x1cUpdateRegistryContractParams\x12%.injective.wasmx.v1.MsgUpdateContract\x1a-.injective.wasmx.v1.MsgUpdateContractResponse\x12t\n\x18\x41\x63tivateRegistryContract\x12\'.injective.wasmx.v1.MsgActivateContract\x1a/.injective.wasmx.v1.MsgActivateContractResponse\x12z\n\x1a\x44\x65\x61\x63tivateRegistryContract\x12).injective.wasmx.v1.MsgDeactivateContract\x1a\x31.injective.wasmx.v1.MsgDeactivateContractResponse\x12{\n\x15\x45xecuteContractCompat\x12,.injective.wasmx.v1.MsgExecuteContractCompat\x1a\x34.injective.wasmx.v1.MsgExecuteContractCompatResponseBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _MSGUPDATECONTRACT.fields_by_name['admin_address']._options = None
  _MSGUPDATECONTRACT.fields_by_name['admin_address']._serialized_options = b'\310\336\037\001'
  _MSGEXECUTECONTRACTCOMPAT._serialized_start=127
  _MSGEXECUTECONTRACTCOMPAT._serialized_end=215
  _MSGEXECUTECONTRACTCOMPATRESPONSE._serialized_start=217
  _MSGEXECUTECONTRACTCOMPATRESPONSE._serialized_end=265
  _MSGUPDATECONTRACT._serialized_start=268
  _MSGUPDATECONTRACT._serialized_end=396
  _MSGUPDATECONTRACTRESPONSE._serialized_start=398
  _MSGUPDATECONTRACTRESPONSE._serialized_end=425
  _MSGACTIVATECONTRACT._serialized_start=427
  _MSGACTIVATECONTRACT._serialized_end=490
  _MSGACTIVATECONTRACTRESPONSE._serialized_start=492
  _MSGACTIVATECONTRACTRESPONSE._serialized_end=521
  _MSGDEACTIVATECONTRACT._serialized_start=523
  _MSGDEACTIVATECONTRACT._serialized_end=588
  _MSGDEACTIVATECONTRACTRESPONSE._serialized_start=590
  _MSGDEACTIVATECONTRACTRESPONSE._serialized_end=621
  _MSG._serialized_start=624
  _MSG._serialized_end=1114
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/auction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/auction/v1beta1/auction.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"{\n\x06Params\x12\x16\n\x0e\x61uction_period\x18\x01 \x01(\x03\x12S\n\x1bmin_next_bid_increment_rate\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"s\n\x03\x42id\x12+\n\x06\x62idder\x18\x01 \x01(\tB\x1b\xea\xde\x1f\x06\x62idder\xf2\xde\x1f\ryaml:\"bidder\"\x12?\n\x06\x61mount\x18\x02 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\"j\n\x08\x45ventBid\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12?\n\x06\x61mount\x18\x02 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04\"t\n\x12\x45ventAuctionResult\x12\x0e\n\x06winner\x18\x01 \x01(\t\x12?\n\x06\x61mount\x18\x02 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04\"\x9d\x01\n\x11\x45ventAuctionStart\x12\r\n\x05round\x18\x01 \x01(\x04\x12\x18\n\x10\x65nding_timestamp\x18\x02 \x01(\x03\x12_\n\nnew_basket\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.auction_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types'
  _PARAMS.fields_by_name['min_next_bid_increment_rate']._options = None
  _PARAMS.fields_by_name['min_next_bid_increment_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001'
  _BID.fields_by_name['bidder']._options = None
  _BID.fields_by_name['bidder']._serialized_options = b'\352\336\037\006bidder\362\336\037\ryaml:\"bidder\"'
  _BID.fields_by_name['amount']._options = None
  _BID.fields_by_name['amount']._serialized_options = b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000'
  _EVENTBID.fields_by_name['amount']._options = None
  _EVENTBID.fields_by_name['amount']._serialized_options = b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000'
  _EVENTAUCTIONRESULT.fields_by_name['amount']._options = None
  _EVENTAUCTIONRESULT.fields_by_name['amount']._serialized_options = b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000'
  _EVENTAUCTIONSTART.fields_by_name['new_basket']._options = None
  _EVENTAUCTIONSTART.fields_by_name['new_basket']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _PARAMS._serialized_start=124
  _PARAMS._serialized_end=247
  _BID._serialized_start=249
  _BID._serialized_end=364
  _EVENTBID._serialized_start=366
  _EVENTBID._serialized_end=472
  _EVENTAUCTIONRESULT._serialized_start=474
  _EVENTAUCTIONRESULT._serialized_end=590
  _EVENTAUCTIONSTART._serialized_start=593
  _EVENTAUCTIONSTART._serialized_end=750
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"injective/auction/v1beta1/tx.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"f\n\x06MsgBid\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x33\n\nbid_amount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x10\n\x0eMsgBidResponse2Z\n\x03Msg\x12S\n\x03\x42id\x12!.injective.auction.v1beta1.MsgBid\x1a).injective.auction.v1beta1.MsgBidResponseBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types'
  _MSGBID.fields_by_name['bid_amount']._options = None
  _MSGBID.fields_by_name['bid_amount']._serialized_options = b'\310\336\037\000'
  _MSGBID._options = None
  _MSGBID._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGBID._serialized_start=119
  _MSGBID._serialized_end=221
  _MSGBIDRESPONSE._serialized_start=223
  _MSGBIDRESPONSE._serialized_end=239
  _MSG._serialized_start=241
  _MSG._serialized_end=331
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.peggy.v1 import genesis_pb2 as injective_dot_peggy_dot_v1_dot_genesis__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from injective.peggy.v1 import msgs_pb2 as injective_dot_peggy_dot_v1_dot_msgs__pb2
from injective.peggy.v1 import pool_pb2 as injective_dot_peggy_dot_v1_dot_pool__pb2
from injective.peggy.v1 import batch_pb2 as injective_dot_peggy_dot_v1_dot_batch__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/peggy/v1/query.proto\x12\x12injective.peggy.v1\x1a injective/peggy/v1/genesis.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1dinjective/peggy/v1/msgs.proto\x1a\x1dinjective/peggy/v1/pool.proto\x1a\x1einjective/peggy/v1/batch.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\"\x14\n\x12QueryParamsRequest\"G\n\x13QueryParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x1b\n\x19QueryCurrentValsetRequest\"H\n\x1aQueryCurrentValsetResponse\x12*\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.Valset\"*\n\x19QueryValsetRequestRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\"H\n\x1aQueryValsetRequestResponse\x12*\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.Valset\";\n\x19QueryValsetConfirmRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"S\n\x1aQueryValsetConfirmResponse\x12\x35\n\x07\x63onfirm\x18\x01 \x01(\x0b\x32$.injective.peggy.v1.MsgValsetConfirm\"2\n!QueryValsetConfirmsByNonceRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\"\\\n\"QueryValsetConfirmsByNonceResponse\x12\x36\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32$.injective.peggy.v1.MsgValsetConfirm\" \n\x1eQueryLastValsetRequestsRequest\"N\n\x1fQueryLastValsetRequestsResponse\x12+\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.Valset\"=\n*QueryLastPendingValsetRequestByAddrRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"Z\n+QueryLastPendingValsetRequestByAddrResponse\x12+\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.Valset\"\x16\n\x14QueryBatchFeeRequest\"I\n\x15QueryBatchFeeResponse\x12\x30\n\tbatchFees\x18\x01 \x03(\x0b\x32\x1d.injective.peggy.v1.BatchFees\"<\n)QueryLastPendingBatchRequestByAddrRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"`\n*QueryLastPendingBatchRequestByAddrResponse\x12\x32\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\"\x1f\n\x1dQueryOutgoingTxBatchesRequest\"V\n\x1eQueryOutgoingTxBatchesResponse\x12\x34\n\x07\x62\x61tches\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\"J\n\x1fQueryBatchRequestByNonceRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"V\n QueryBatchRequestByNonceResponse\x12\x32\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\"D\n\x19QueryBatchConfirmsRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"S\n\x1aQueryBatchConfirmsResponse\x12\x35\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.MsgConfirmBatch\".\n\x1bQueryLastEventByAddrRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\\\n\x1cQueryLastEventByAddrResponse\x12<\n\x10last_claim_event\x18\x01 \x01(\x0b\x32\".injective.peggy.v1.LastClaimEvent\")\n\x18QueryERC20ToDenomRequest\x12\r\n\x05\x65rc20\x18\x01 \x01(\t\"E\n\x19QueryERC20ToDenomResponse\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x19\n\x11\x63osmos_originated\x18\x02 \x01(\x08\")\n\x18QueryDenomToERC20Request\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"E\n\x19QueryDenomToERC20Response\x12\r\n\x05\x65rc20\x18\x01 \x01(\t\x12\x19\n\x11\x63osmos_originated\x18\x02 \x01(\x08\"@\n#QueryDelegateKeysByValidatorAddress\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"`\n+QueryDelegateKeysByValidatorAddressResponse\x12\x13\n\x0b\x65th_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"4\n\x1dQueryDelegateKeysByEthAddress\x12\x13\n\x0b\x65th_address\x18\x01 \x01(\t\"`\n%QueryDelegateKeysByEthAddressResponse\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"F\n&QueryDelegateKeysByOrchestratorAddress\x12\x1c\n\x14orchestrator_address\x18\x01 \x01(\t\"`\n.QueryDelegateKeysByOrchestratorAddressResponse\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x02 \x01(\t\"/\n\x15QueryPendingSendToEth\x12\x16\n\x0esender_address\x18\x01 \x01(\t\"\xaa\x01\n\x1dQueryPendingSendToEthResponse\x12\x44\n\x14transfers_in_batches\x18\x01 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTx\x12\x43\n\x13unbatched_transfers\x18\x02 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTx\"\x19\n\x17QueryModuleStateRequest\"K\n\x18QueryModuleStateResponse\x12/\n\x05state\x18\x01 \x01(\x0b\x32 .injective.peggy.v1.GenesisState2\xb8\x19\n\x05Query\x12s\n\x06Params\x12&.injective.peggy.v1.QueryParamsRequest\x1a\'.injective.peggy.v1.QueryParamsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/params\x12\x90\x01\n\rCurrentValset\x12-.injective.peggy.v1.QueryCurrentValsetRequest\x1a..injective.peggy.v1.QueryCurrentValsetResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/current\x12\x88\x01\n\rValsetRequest\x12-.injective.peggy.v1.QueryValsetRequestRequest\x1a..injective.peggy.v1.QueryValsetRequestResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/valset\x12\x90\x01\n\rValsetConfirm\x12-.injective.peggy.v1.QueryValsetConfirmRequest\x1a..injective.peggy.v1.QueryValsetConfirmResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/confirm\x12\xaa\x01\n\x15ValsetConfirmsByNonce\x12\x35.injective.peggy.v1.QueryValsetConfirmsByNonceRequest\x1a\x36.injective.peggy.v1.QueryValsetConfirmsByNonceResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/confirms/{nonce}\x12\xa0\x01\n\x12LastValsetRequests\x12\x32.injective.peggy.v1.QueryLastValsetRequestsRequest\x1a\x33.injective.peggy.v1.QueryLastValsetRequestsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/peggy/v1/valset/requests\x12\xc0\x01\n\x1eLastPendingValsetRequestByAddr\x12>.injective.peggy.v1.QueryLastPendingValsetRequestByAddrRequest\x1a?.injective.peggy.v1.QueryLastPendingValsetRequestByAddrResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/peggy/v1/valset/last\x12\x9e\x01\n\x0fLastEventByAddr\x12/.injective.peggy.v1.QueryLastEventByAddrRequest\x1a\x30.injective.peggy.v1.QueryLastEventByAddrResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /peggy/v1/oracle/event/{address}\x12\x9a\x01\n\x13GetPendingSendToEth\x12).injective.peggy.v1.QueryPendingSendToEth\x1a\x31.injective.peggy.v1.QueryPendingSendToEthResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/peggy/v1/pending_send_to_eth\x12}\n\tBatchFees\x12(.injective.peggy.v1.QueryBatchFeeRequest\x1a).injective.peggy.v1.QueryBatchFeeResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/peggy/v1/batchfees\x12\x9e\x01\n\x11OutgoingTxBatches\x12\x31.injective.peggy.v1.QueryOutgoingTxBatchesRequest\x1a\x32.injective.peggy.v1.QueryOutgoingTxBatchesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/batch/outgoingtx\x12\xbc\x01\n\x1dLastPendingBatchRequestByAddr\x12=.injective.peggy.v1.QueryLastPendingBatchRequestByAddrRequest\x1a>.injective.peggy.v1.QueryLastPendingBatchRequestByAddrResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/peggy/v1/batch/last\x12\x99\x01\n\x13\x42\x61tchRequestByNonce\x12\x33.injective.peggy.v1.QueryBatchRequestByNonceRequest\x1a\x34.injective.peggy.v1.QueryBatchRequestByNonceResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/peggy/v1/batch\x12\x90\x01\n\rBatchConfirms\x12-.injective.peggy.v1.QueryBatchConfirmsRequest\x1a..injective.peggy.v1.QueryBatchConfirmsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/batch/confirms\x12\x9f\x01\n\x0c\x45RC20ToDenom\x12,.injective.peggy.v1.QueryERC20ToDenomRequest\x1a-.injective.peggy.v1.QueryERC20ToDenomResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/erc20_to_denom\x12\x9f\x01\n\x0c\x44\x65nomToERC20\x12,.injective.peggy.v1.QueryDenomToERC20Request\x1a-.injective.peggy.v1.QueryDenomToERC20Response\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/denom_to_erc20\x12\xc9\x01\n\x19GetDelegateKeyByValidator\x12\x37.injective.peggy.v1.QueryDelegateKeysByValidatorAddress\x1a?.injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/query_delegate_keys_by_validator\x12\xb1\x01\n\x13GetDelegateKeyByEth\x12\x31.injective.peggy.v1.QueryDelegateKeysByEthAddress\x1a\x39.injective.peggy.v1.QueryDelegateKeysByEthAddressResponse\",\x82\xd3\xe4\x93\x02&\x12$/peggy/v1/query_delegate_keys_by_eth\x12\xd5\x01\n\x1cGetDelegateKeyByOrchestrator\x12:.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddress\x1a\x42.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse\"5\x82\xd3\xe4\x93\x02/\x12-/peggy/v1/query_delegate_keys_by_orchestrator\x12\x8d\x01\n\x10PeggyModuleState\x12+.injective.peggy.v1.QueryModuleStateRequest\x1a,.injective.peggy.v1.QueryModuleStateResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/peggy/v1/module_stateBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\022\022\020/peggy/v1/params'
  _QUERY.methods_by_name['CurrentValset']._options = None
  _QUERY.methods_by_name['CurrentValset']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/valset/current'
  _QUERY.methods_by_name['ValsetRequest']._options = None
  _QUERY.methods_by_name['ValsetRequest']._serialized_options = b'\202\323\344\223\002\022\022\020/peggy/v1/valset'
  _QUERY.methods_by_name['ValsetConfirm']._options = None
  _QUERY.methods_by_name['ValsetConfirm']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/valset/confirm'
  _QUERY.methods_by_name['ValsetConfirmsByNonce']._options = None
  _QUERY.methods_by_name['ValsetConfirmsByNonce']._serialized_options = b'\202\323\344\223\002\034\022\032/peggy/v1/confirms/{nonce}'
  _QUERY.methods_by_name['LastValsetRequests']._options = None
  _QUERY.methods_by_name['LastValsetRequests']._serialized_options = b'\202\323\344\223\002\033\022\031/peggy/v1/valset/requests'
  _QUERY.methods_by_name['LastPendingValsetRequestByAddr']._options = None
  _QUERY.methods_by_name['LastPendingValsetRequestByAddr']._serialized_options = b'\202\323\344\223\002\027\022\025/peggy/v1/valset/last'
  _QUERY.methods_by_name['LastEventByAddr']._options = None
  _QUERY.methods_by_name['LastEventByAddr']._serialized_options = b'\202\323\344\223\002\"\022 /peggy/v1/oracle/event/{address}'
  _QUERY.methods_by_name['GetPendingSendToEth']._options = None
  _QUERY.methods_by_name['GetPendingSendToEth']._serialized_options = b'\202\323\344\223\002\037\022\035/peggy/v1/pending_send_to_eth'
  _QUERY.methods_by_name['BatchFees']._options = None
  _QUERY.methods_by_name['BatchFees']._serialized_options = b'\202\323\344\223\002\025\022\023/peggy/v1/batchfees'
  _QUERY.methods_by_name['OutgoingTxBatches']._options = None
  _QUERY.methods_by_name['OutgoingTxBatches']._serialized_options = b'\202\323\344\223\002\034\022\032/peggy/v1/batch/outgoingtx'
  _QUERY.methods_by_name['LastPendingBatchRequestByAddr']._options = None
  _QUERY.methods_by_name['LastPendingBatchRequestByAddr']._serialized_options = b'\202\323\344\223\002\026\022\024/peggy/v1/batch/last'
  _QUERY.methods_by_name['BatchRequestByNonce']._options = None
  _QUERY.methods_by_name['BatchRequestByNonce']._serialized_options = b'\202\323\344\223\002\021\022\017/peggy/v1/batch'
  _QUERY.methods_by_name['BatchConfirms']._options = None
  _QUERY.methods_by_name['BatchConfirms']._serialized_options = b'\202\323\344\223\002\032\022\030/peggy/v1/batch/confirms'
  _QUERY.methods_by_name['ERC20ToDenom']._options = None
  _QUERY.methods_by_name['ERC20ToDenom']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/erc20_to_denom'
  _QUERY.methods_by_name['DenomToERC20']._options = None
  _QUERY.methods_by_name['DenomToERC20']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/denom_to_erc20'
  _QUERY.methods_by_name['GetDelegateKeyByValidator']._options = None
  _QUERY.methods_by_name['GetDelegateKeyByValidator']._serialized_options = b'\202\323\344\223\002,\022*/peggy/v1/query_delegate_keys_by_validator'
  _QUERY.methods_by_name['GetDelegateKeyByEth']._options = None
  _QUERY.methods_by_name['GetDelegateKeyByEth']._serialized_options = b'\202\323\344\223\002&\022$/peggy/v1/query_delegate_keys_by_eth'
  _QUERY.methods_by_name['GetDelegateKeyByOrchestrator']._options = None
  _QUERY.methods_by_name['GetDelegateKeyByOrchestrator']._serialized_options = b'\202\323\344\223\002/\022-/peggy/v1/query_delegate_keys_by_orchestrator'
  _QUERY.methods_by_name['PeggyModuleState']._options = None
  _QUERY.methods_by_name['PeggyModuleState']._serialized_options = b'\202\323\344\223\002\030\022\026/peggy/v1/module_state'
  _QUERYPARAMSREQUEST._serialized_start=266
  _QUERYPARAMSREQUEST._serialized_end=286
  _QUERYPARAMSRESPONSE._serialized_start=288
  _QUERYPARAMSRESPONSE._serialized_end=359
  _QUERYCURRENTVALSETREQUEST._serialized_start=361
  _QUERYCURRENTVALSETREQUEST._serialized_end=388
  _QUERYCURRENTVALSETRESPONSE._serialized_start=390
  _QUERYCURRENTVALSETRESPONSE._serialized_end=462
  _QUERYVALSETREQUESTREQUEST._serialized_start=464
  _QUERYVALSETREQUESTREQUEST._serialized_end=506
  _QUERYVALSETREQUESTRESPONSE._serialized_start=508
  _QUERYVALSETREQUESTRESPONSE._serialized_end=580
  _QUERYVALSETCONFIRMREQUEST._serialized_start=582
  _QUERYVALSETCONFIRMREQUEST._serialized_end=641
  _QUERYVALSETCONFIRMRESPONSE._serialized_start=643
  _QUERYVALSETCONFIRMRESPONSE._serialized_end=726
  _QUERYVALSETCONFIRMSBYNONCEREQUEST._serialized_start=728
  _QUERYVALSETCONFIRMSBYNONCEREQUEST._serialized_end=778
  _QUERYVALSETCONFIRMSBYNONCERESPONSE._serialized_start=780
  _QUERYVALSETCONFIRMSBYNONCERESPONSE._serialized_end=872
  _QUERYLASTVALSETREQUESTSREQUEST._serialized_start=874
  _QUERYLASTVALSETREQUESTSREQUEST._serialized_end=906
  _QUERYLASTVALSETREQUESTSRESPONSE._serialized_start=908
  _QUERYLASTVALSETREQUESTSRESPONSE._serialized_end=986
  _QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST._serialized_start=988
  _QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST._serialized_end=1049
  _QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE._serialized_start=1051
  _QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE._serialized_end=1141
  _QUERYBATCHFEEREQUEST._serialized_start=1143
  _QUERYBATCHFEEREQUEST._serialized_end=1165
  _QUERYBATCHFEERESPONSE._serialized_start=1167
  _QUERYBATCHFEERESPONSE._serialized_end=1240
  _QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST._serialized_start=1242
  _QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST._serialized_end=1302
  _QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE._serialized_start=1304
  _QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE._serialized_end=1400
  _QUERYOUTGOINGTXBATCHESREQUEST._serialized_start=1402
  _QUERYOUTGOINGTXBATCHESREQUEST._serialized_end=1433
  _QUERYOUTGOINGTXBATCHESRESPONSE._serialized_start=1435
  _QUERYOUTGOINGTXBATCHESRESPONSE._serialized_end=1521
  _QUERYBATCHREQUESTBYNONCEREQUEST._serialized_start=1523
  _QUERYBATCHREQUESTBYNONCEREQUEST._serialized_end=1597
  _QUERYBATCHREQUESTBYNONCERESPONSE._serialized_start=1599
  _QUERYBATCHREQUESTBYNONCERESPONSE._serialized_end=1685
  _QUERYBATCHCONFIRMSREQUEST._serialized_start=1687
  _QUERYBATCHCONFIRMSREQUEST._serialized_end=1755
  _QUERYBATCHCONFIRMSRESPONSE._serialized_start=1757
  _QUERYBATCHCONFIRMSRESPONSE._serialized_end=1840
  _QUERYLASTEVENTBYADDRREQUEST._serialized_start=1842
  _QUERYLASTEVENTBYADDRREQUEST._serialized_end=1888
  _QUERYLASTEVENTBYADDRRESPONSE._serialized_start=1890
  _QUERYLASTEVENTBYADDRRESPONSE._serialized_end=1982
  _QUERYERC20TODENOMREQUEST._serialized_start=1984
  _QUERYERC20TODENOMREQUEST._serialized_end=2025
  _QUERYERC20TODENOMRESPONSE._serialized_start=2027
  _QUERYERC20TODENOMRESPONSE._serialized_end=2096
  _QUERYDENOMTOERC20REQUEST._serialized_start=2098
  _QUERYDENOMTOERC20REQUEST._serialized_end=2139
  _QUERYDENOMTOERC20RESPONSE._serialized_start=2141
  _QUERYDENOMTOERC20RESPONSE._serialized_end=2210
  _QUERYDELEGATEKEYSBYVALIDATORADDRESS._serialized_start=2212
  _QUERYDELEGATEKEYSBYVALIDATORADDRESS._serialized_end=2276
  _QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE._serialized_start=2278
  _QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE._serialized_end=2374
  _QUERYDELEGATEKEYSBYETHADDRESS._serialized_start=2376
  _QUERYDELEGATEKEYSBYETHADDRESS._serialized_end=2428
  _QUERYDELEGATEKEYSBYETHADDRESSRESPONSE._serialized_start=2430
  _QUERYDELEGATEKEYSBYETHADDRESSRESPONSE._serialized_end=2526
  _QUERYDELEGATEKEYSBYORCHESTRATORADDRESS._serialized_start=2528
  _QUERYDELEGATEKEYSBYORCHESTRATORADDRESS._serialized_end=2598
  _QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE._serialized_start=2600
  _QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE._serialized_end=2696
  _QUERYPENDINGSENDTOETH._serialized_start=2698
  _QUERYPENDINGSENDTOETH._serialized_end=2745
  _QUERYPENDINGSENDTOETHRESPONSE._serialized_start=2748
  _QUERYPENDINGSENDTOETHRESPONSE._serialized_end=2918
  _QUERYMODULESTATEREQUEST._serialized_start=2920
  _QUERYMODULESTATEREQUEST._serialized_end=2945
  _QUERYMODULESTATERESPONSE._serialized_start=2947
  _QUERYMODULESTATERESPONSE._serialized_end=3022
  _QUERY._serialized_start=3025
  _QUERY._serialized_end=6281
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/client/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eibc/core/client/v1/query.proto\x12\x12ibc.core.client.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\",\n\x17QueryClientStateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\x8d\x01\n\x18QueryClientStateResponse\x12*\n\x0c\x63lient_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"V\n\x18QueryClientStatesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xba\x01\n\x19QueryClientStatesResponse\x12`\n\rclient_states\x18\x01 \x03(\x0b\x32).ibc.core.client.v1.IdentifiedClientStateB\x1e\xc8\xde\x1f\x00\xaa\xdf\x1f\x16IdentifiedClientStates\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"x\n\x1aQueryConsensusStateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x17\n\x0frevision_number\x18\x02 \x01(\x04\x12\x17\n\x0frevision_height\x18\x03 \x01(\x04\x12\x15\n\rlatest_height\x18\x04 \x01(\x08\"\x93\x01\n\x1bQueryConsensusStateResponse\x12-\n\x0f\x63onsensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05proof\x18\x02 \x01(\x0c\x12\x36\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00\"l\n\x1bQueryConsensusStatesRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xa9\x01\n\x1cQueryConsensusStatesResponse\x12L\n\x10\x63onsensus_states\x18\x01 \x03(\x0b\x32,.ibc.core.client.v1.ConsensusStateWithHeightB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"-\n\x18QueryClientStatusRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\"+\n\x19QueryClientStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x1a\n\x18QueryClientParamsRequest\"G\n\x19QueryClientParamsResponse\x12*\n\x06params\x18\x01 \x01(\x0b\x32\x1a.ibc.core.client.v1.Params\"!\n\x1fQueryUpgradedClientStateRequest\"W\n QueryUpgradedClientStateResponse\x12\x33\n\x15upgraded_client_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"$\n\"QueryUpgradedConsensusStateRequest\"]\n#QueryUpgradedConsensusStateResponse\x12\x36\n\x18upgraded_consensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any2\x81\x0b\n\x05Query\x12\x9f\x01\n\x0b\x43lientState\x12+.ibc.core.client.v1.QueryClientStateRequest\x1a,.ibc.core.client.v1.QueryClientStateResponse\"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_states/{client_id}\x12\x96\x01\n\x0c\x43lientStates\x12,.ibc.core.client.v1.QueryClientStatesRequest\x1a-.ibc.core.client.v1.QueryClientStatesResponse\")\x82\xd3\xe4\x93\x02#\x12!/ibc/core/client/v1/client_states\x12\xdf\x01\n\x0e\x43onsensusState\x12..ibc.core.client.v1.QueryConsensusStateRequest\x1a/.ibc.core.client.v1.QueryConsensusStateResponse\"l\x82\xd3\xe4\x93\x02\x66\x12\x64/ibc/core/client/v1/consensus_states/{client_id}/revision/{revision_number}/height/{revision_height}\x12\xae\x01\n\x0f\x43onsensusStates\x12/.ibc.core.client.v1.QueryConsensusStatesRequest\x1a\x30.ibc.core.client.v1.QueryConsensusStatesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/ibc/core/client/v1/consensus_states/{client_id}\x12\xa2\x01\n\x0c\x43lientStatus\x12,.ibc.core.client.v1.QueryClientStatusRequest\x1a-.ibc.core.client.v1.QueryClientStatusResponse\"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/client_status/{client_id}\x12\x8a\x01\n\x0c\x43lientParams\x12,.ibc.core.client.v1.QueryClientParamsRequest\x1a-.ibc.core.client.v1.QueryClientParamsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/ibc/client/v1/params\x12\xb4\x01\n\x13UpgradedClientState\x12\x33.ibc.core.client.v1.QueryUpgradedClientStateRequest\x1a\x34.ibc.core.client.v1.QueryUpgradedClientStateResponse\"2\x82\xd3\xe4\x93\x02,\x12*/ibc/core/client/v1/upgraded_client_states\x12\xc0\x01\n\x16UpgradedConsensusState\x12\x36.ibc.core.client.v1.QueryUpgradedConsensusStateRequest\x1a\x37.ibc.core.client.v1.QueryUpgradedConsensusStateResponse\"5\x82\xd3\xe4\x93\x02/\x12-/ibc/core/client/v1/upgraded_consensus_statesB:Z8github.com/cosmos/ibc-go/v2/modules/core/02-client/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z8github.com/cosmos/ibc-go/v2/modules/core/02-client/types'
  _QUERYCLIENTSTATERESPONSE.fields_by_name['proof_height']._options = None
  _QUERYCLIENTSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYCLIENTSTATESRESPONSE.fields_by_name['client_states']._options = None
  _QUERYCLIENTSTATESRESPONSE.fields_by_name['client_states']._serialized_options = b'\310\336\037\000\252\337\037\026IdentifiedClientStates'
  _QUERYCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._options = None
  _QUERYCONSENSUSSTATERESPONSE.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _QUERYCONSENSUSSTATESRESPONSE.fields_by_name['consensus_states']._options = None
  _QUERYCONSENSUSSTATESRESPONSE.fields_by_name['consensus_states']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['ClientState']._options = None
  _QUERY.methods_by_name['ClientState']._serialized_options = b'\202\323\344\223\002/\022-/ibc/core/client/v1/client_states/{client_id}'
  _QUERY.methods_by_name['ClientStates']._options = None
  _QUERY.methods_by_name['ClientStates']._serialized_options = b'\202\323\344\223\002#\022!/ibc/core/client/v1/client_states'
  _QUERY.methods_by_name['ConsensusState']._options = None
  _QUERY.methods_by_name['ConsensusState']._serialized_options = b'\202\323\344\223\002f\022d/ibc/core/client/v1/consensus_states/{client_id}/revision/{revision_number}/height/{revision_height}'
  _QUERY.methods_by_name['ConsensusStates']._options = None
  _QUERY.methods_by_name['ConsensusStates']._serialized_options = b'\202\323\344\223\0022\0220/ibc/core/client/v1/consensus_states/{client_id}'
  _QUERY.methods_by_name['ClientStatus']._options = None
  _QUERY.methods_by_name['ClientStatus']._serialized_options = b'\202\323\344\223\002/\022-/ibc/core/client/v1/client_status/{client_id}'
  _QUERY.methods_by_name['ClientParams']._options = None
  _QUERY.methods_by_name['ClientParams']._serialized_options = b'\202\323\344\223\002\027\022\025/ibc/client/v1/params'
  _QUERY.methods_by_name['UpgradedClientState']._options = None
  _QUERY.methods_by_name['UpgradedClientState']._serialized_options = b'\202\323\344\223\002,\022*/ibc/core/client/v1/upgraded_client_states'
  _QUERY.methods_by_name['UpgradedConsensusState']._options = None
  _QUERY.methods_by_name['UpgradedConsensusState']._serialized_options = b'\202\323\344\223\002/\022-/ibc/core/client/v1/upgraded_consensus_states'
  _QUERYCLIENTSTATEREQUEST._serialized_start=210
  _QUERYCLIENTSTATEREQUEST._serialized_end=254
  _QUERYCLIENTSTATERESPONSE._serialized_start=257
  _QUERYCLIENTSTATERESPONSE._serialized_end=398
  _QUERYCLIENTSTATESREQUEST._serialized_start=400
  _QUERYCLIENTSTATESREQUEST._serialized_end=486
  _QUERYCLIENTSTATESRESPONSE._serialized_start=489
  _QUERYCLIENTSTATESRESPONSE._serialized_end=675
  _QUERYCONSENSUSSTATEREQUEST._serialized_start=677
  _QUERYCONSENSUSSTATEREQUEST._serialized_end=797
  _QUERYCONSENSUSSTATERESPONSE._serialized_start=800
  _QUERYCONSENSUSSTATERESPONSE._serialized_end=947
  _QUERYCONSENSUSSTATESREQUEST._serialized_start=949
  _QUERYCONSENSUSSTATESREQUEST._serialized_end=1057
  _QUERYCONSENSUSSTATESRESPONSE._serialized_start=1060
  _QUERYCONSENSUSSTATESRESPONSE._serialized_end=1229
  _QUERYCLIENTSTATUSREQUEST._serialized_start=1231
  _QUERYCLIENTSTATUSREQUEST._serialized_end=1276
  _QUERYCLIENTSTATUSRESPONSE._serialized_start=1278
  _QUERYCLIENTSTATUSRESPONSE._serialized_end=1321
  _QUERYCLIENTPARAMSREQUEST._serialized_start=1323
  _QUERYCLIENTPARAMSREQUEST._serialized_end=1349
  _QUERYCLIENTPARAMSRESPONSE._serialized_start=1351
  _QUERYCLIENTPARAMSRESPONSE._serialized_end=1422
  _QUERYUPGRADEDCLIENTSTATEREQUEST._serialized_start=1424
  _QUERYUPGRADEDCLIENTSTATEREQUEST._serialized_end=1457
  _QUERYUPGRADEDCLIENTSTATERESPONSE._serialized_start=1459
  _QUERYUPGRADEDCLIENTSTATERESPONSE._serialized_end=1546
  _QUERYUPGRADEDCONSENSUSSTATEREQUEST._serialized_start=1548
  _QUERYUPGRADEDCONSENSUSSTATEREQUEST._serialized_end=1584
  _QUERYUPGRADEDCONSENSUSSTATERESPONSE._serialized_start=1586
  _QUERYUPGRADEDCONSENSUSSTATERESPONSE._serialized_end=1679
  _QUERY._serialized_start=1682
  _QUERY._serialized_end=3091
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/authz/v1beta1/event.proto\x12\x14\x63osmos.authz.v1beta1\"D\n\nEventGrant\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12\x0f\n\x07granter\x18\x03 \x01(\t\x12\x0f\n\x07grantee\x18\x04 \x01(\t\"E\n\x0b\x45ventRevoke\x12\x14\n\x0cmsg_type_url\x18\x02 \x01(\t\x12\x0f\n\x07granter\x18\x03 \x01(\t\x12\x0f\n\x07grantee\x18\x04 \x01(\tB&Z$github.com/cosmos/cosmos-sdk/x/authzb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.event_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz'
  _EVENTGRANT._serialized_start=58
  _EVENTGRANT._serialized_end=126
  _EVENTREVOKE._serialized_start=128
  _EVENTREVOKE._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crisis/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/crisis/v1beta1/genesis.proto\x12\x15\x63osmos.crisis.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\\\n\x0cGenesisState\x12L\n\x0c\x63onstant_fee\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"constant_fee\"B-Z+github.com/cosmos/cosmos-sdk/x/crisis/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crisis.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/cosmos/cosmos-sdk/x/crisis/types'
  _GENESISSTATE.fields_by_name['constant_fee']._options = None
  _GENESISSTATE.fields_by_name['constant_fee']._serialized_options = b'\310\336\037\000\362\336\037\023yaml:\"constant_fee\"'
  _GENESISSTATE._serialized_start=116
  _GENESISSTATE._serialized_end=208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/crypto/v1beta1/ethsecp256k1/keys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0injective/crypto/v1beta1/ethsecp256k1/keys.proto\x12%injective.crypto.v1beta1.ethsecp256k1\x1a\x14gogoproto/gogo.proto\"\x1b\n\x06PubKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c:\x04\x98\xa0\x1f\x00\"\x16\n\x07PrivKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/crypto/ethsecp256k1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.crypto.v1beta1.ethsecp256k1.keys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/crypto/ethsecp256k1'
  _PUBKEY._options = None
  _PUBKEY._serialized_options = b'\230\240\037\000'
  _PUBKEY._serialized_start=113
  _PUBKEY._serialized_end=140
  _PRIVKEY._serialized_start=142
  _PRIVKEY._serialized_end=164
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.applications.transfer.v1 import transfer_pb2 as ibc_dot_applications_dot_transfer_dot_v1_dot_transfer__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ibc/applications/transfer/v1/genesis.proto\x12\x1cibc.applications.transfer.v1\x1a+ibc/applications/transfer/v1/transfer.proto\x1a\x14gogoproto/gogo.proto\"\xd6\x01\n\x0cGenesisState\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12\x65\n\x0c\x64\x65nom_traces\x18\x02 \x03(\x0b\x32(.ibc.applications.transfer.v1.DenomTraceB%\xaa\xdf\x1f\x06Traces\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"denom_traces\"\x12:\n\x06params\x18\x03 \x01(\x0b\x32$.ibc.applications.transfer.v1.ParamsB\x04\xc8\xde\x1f\x00\x42\x39Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/cosmos/ibc-go/v2/modules/apps/transfer/types'
  _GENESISSTATE.fields_by_name['port_id']._options = None
  _GENESISSTATE.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _GENESISSTATE.fields_by_name['denom_traces']._options = None
  _GENESISSTATE.fields_by_name['denom_traces']._serialized_options = b'\252\337\037\006Traces\310\336\037\000\362\336\037\023yaml:\"denom_traces\"'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=144
  _GENESISSTATE._serialized_end=358
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/store/v1beta1/listening.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)cosmos/base/store/v1beta1/listening.proto\x12\x19\x63osmos.base.store.v1beta1\"L\n\x0bStoreKVPair\x12\x11\n\tstore_key\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\x08\x12\x0b\n\x03key\x18\x03 \x01(\x0c\x12\r\n\x05value\x18\x04 \x01(\x0c\x42*Z(github.com/cosmos/cosmos-sdk/store/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.store.v1beta1.listening_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/store/types'
  _STOREKVPAIR._serialized_start=72
  _STOREKVPAIR._serialized_end=148
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/evidence/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/evidence/v1beta1/query.proto\x12\x17\x63osmos.evidence.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\"g\n\x14QueryEvidenceRequest\x12O\n\revidence_hash\x18\x01 \x01(\x0c\x42\x38\xfa\xde\x1f\x34github.com/tendermint/tendermint/libs/bytes.HexBytes\"?\n\x15QueryEvidenceResponse\x12&\n\x08\x65vidence\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"U\n\x17QueryAllEvidenceRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x7f\n\x18QueryAllEvidenceResponse\x12&\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xce\x02\n\x05Query\x12\xa4\x01\n\x08\x45vidence\x12-.cosmos.evidence.v1beta1.QueryEvidenceRequest\x1a..cosmos.evidence.v1beta1.QueryEvidenceResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/cosmos/evidence/v1beta1/evidence/{evidence_hash}\x12\x9d\x01\n\x0b\x41llEvidence\x12\x30.cosmos.evidence.v1beta1.QueryAllEvidenceRequest\x1a\x31.cosmos.evidence.v1beta1.QueryAllEvidenceResponse\")\x82\xd3\xe4\x93\x02#\x12!/cosmos/evidence/v1beta1/evidenceB/Z-github.com/cosmos/cosmos-sdk/x/evidence/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/evidence/types'
  _QUERYEVIDENCEREQUEST.fields_by_name['evidence_hash']._options = None
  _QUERYEVIDENCEREQUEST.fields_by_name['evidence_hash']._serialized_options = b'\372\336\0374github.com/tendermint/tendermint/libs/bytes.HexBytes'
  _QUERY.methods_by_name['Evidence']._options = None
  _QUERY.methods_by_name['Evidence']._serialized_options = b'\202\323\344\223\0023\0221/cosmos/evidence/v1beta1/evidence/{evidence_hash}'
  _QUERY.methods_by_name['AllEvidence']._options = None
  _QUERY.methods_by_name['AllEvidence']._serialized_options = b'\202\323\344\223\002#\022!/cosmos/evidence/v1beta1/evidence'
  _QUERYEVIDENCEREQUEST._serialized_start=187
  _QUERYEVIDENCEREQUEST._serialized_end=290
  _QUERYEVIDENCERESPONSE._serialized_start=292
  _QUERYEVIDENCERESPONSE._serialized_end=355
  _QUERYALLEVIDENCEREQUEST._serialized_start=357
  _QUERYALLEVIDENCEREQUEST._serialized_end=442
  _QUERYALLEVIDENCERESPONSE._serialized_start=444
  _QUERYALLEVIDENCERESPONSE._serialized_end=571
  _QUERY._serialized_start=574
  _QUERY._serialized_end=908
# @@protoc_insertion_point(module_scope)
